/*!
 * @file        main.c
 *
 * @brief       Main program body
 *
 * @version     V1.0.2
 *
 * @date        2023-03-31
 *
 * @attention
 *
 *  Copyright (C) 2023 Geehy Semiconductor
 *
 *  You may not use this file except in compliance with the
 *  GEEHY COPYRIGHT NOTICE (GEEHY SOFTWARE PACKAGE LICENSE).
 *
 *  The program is only for reference, which is distributed in the hope
 *  that it will be useful and instructional for customers to develop
 *  their software. Unless required by applicable law or agreed to in
 *  writing, the program is distributed on an "AS IS" BASIS, WITHOUT
 *  ANY WARRANTY OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the GEEHY SOFTWARE PACKAGE LICENSE for the governing permissions
 *  and limitations under the License.
 */

/* Includes */
#include "main.h"
/** @addtogroup Examples
  @{
*/

/** @addtogroup EINT
  @{
*/

/** @defgroup EINT_Functions Functions
  @{
*/

/*!
 * @brief       Main program
 *
 * @param       None
 *
 * @retval      None
 */
int main(void)
{
    APM_MINI_LEDInit(LED2);
    APM_MINI_LEDInit(LED3);
    APM_MINI_PBInit(BUTTON_KEY1, BUTTON_MODE_EINT);

    APM_MINI_LEDOn(LED2);
    APM_MINI_LEDOff(LED3);

    while(1)
    {
    }
}

/*!
 * @brief       Key interrupt server routine
 *
 * @param       None
 *
 * @retval      None
 */
void Key_Isr(void)
{
    APM_MINI_LEDToggle(LED2);
    APM_MINI_LEDToggle(LED3);

    EINT_ClearIntFlag(EINT_PORT_D);
}

/**@} end of group EINT_Functions */
/**@} end of group EINT */
/**@} end of group Examples */
